# SpDB

**SpDB**是一个[数据集成 (Data Integration)](https://en.wikipedia.org/wiki/Data_integration)工具，其设计目标是将不同来源的科学数据，按照某一全局语义(global schema)组织在同一个命名空间(namespace)下，并以统一的形式（view）提供给用户访问。**主要用途**是为复杂科学计算提供统一的数据访问接口，以实现不同程序和数据库之间的交互和集成。

![SpDB](./docs/figures/SpDB.svg)